@@ -23,6 +23,7 @@ from pathlib import Path
 
 import neurom as nm
 import numpy as np
+from matplotlib.backends.backend_pdf import PdfPages
 from morphio.mut import Morphology
 from tqdm import tqdm
 
@@ -30,6 +31,9 @@ from diameter_synthesis import utils
 from diameter_synthesis.build_diameters import build as build_diameters
 from diameter_synthesis.build_models import build as build_model
 from diameter_synthesis.plotting import plot_distribution_fit
+from diameter_synthesis.simpler_diametrizer import build_simpler_model
+from diameter_synthesis.simpler_diametrizer import plot_model
+from diameter_synthesis.simpler_diametrizer import simpler_diametrizer
 
 L = logging.getLogger(__name__)
 logging.basicConfig(level=os.environ.get("LOGLEVEL", "INFO"))
@@ -40,6 +44,7 @@ class NumpyEncoder(json.JSONEncoder):
 
     def default(self, o):  # pylint: disable=method-hidden
         """Numpy encoder."""
+        # pragma: no cover
         if isinstance(o, np.ndarray):
             return o.tolist()
         if isinstance(o, np.floating):
@@ -67,23 +72,31 @@ def plot_models(morphologies, config, models_params, models_data, ext=".png"):
     if not Path(config["fig_folder"]).exists():
         os.mkdir(config["fig_folder"])
 
-    for mtype in tqdm(morphologies):
-        if not (Path(config["fig_folder"]) / mtype).exists():
-            os.mkdir(Path(config["fig_folder"]) / mtype)
-        for model in config["models"]:
-            fit_tpes = models_data[model][mtype]
-            model_data = models_data[model][mtype]
-            model_param = models_params[model][mtype]
-
-            for fit_tpe in fit_tpes:
-                fig_name = Path(config["fig_folder"]) / mtype / fit_tpe
-                plot_distribution_fit(
-                    model_data[fit_tpe],
-                    model_param[fit_tpe],
-                    config["neurite_types"],
-                    fig_name=fig_name,
-                    ext=ext,
-                )
+    for model in config["models"]:
+        if len(models_data[model][list(morphologies.keys())[0]]) == 3:
+            fig_name = Path(config["fig_folder"]) / f"fit_{model}.pdf"
+            with PdfPages(fig_name) as pdf:
+                for mtype in tqdm(morphologies):
+                    title_str = f"""mtype: {mtype}"""
+                    model_param = models_params[model][mtype]
+                    model_data = models_data[model][mtype]
+                    plot_model(model_param, pdf, title_str, *model_data)
+        else:
+            for mtype in tqdm(morphologies):
+                fit_tpes = models_data[model][mtype]
+                model_data = models_data[model][mtype]
+                model_param = models_params[model][mtype]
+                if not (Path(config["fig_folder"]) / mtype).exists():
+                    os.mkdir(Path(config["fig_folder"]) / mtype)
+                for fit_tpe in fit_tpes:
+                    fig_name = Path(config["fig_folder"]) / mtype / fit_tpe
+                    plot_distribution_fit(
+                        model_data[fit_tpe],
+                        model_param[fit_tpe],
+                        config["neurite_types"],
+                        fig_name=fig_name,
+                        ext=ext,
+                    )
 
 
 def _build_all_models(morphologies, config, plot=False, ext=".png"):
@@ -205,33 +218,12 @@ def run_diameters(config_file, models_params_file):
             list(tqdm(pool.imap(worker, all_neurons), total=len(all_neurons)))
 
 
-def diametrize_single_neuron(neuron, config=None, apical_point_sec_ids=None):
-    """Diametrize single neuron by learning diameter model from it.
+def diametrize_single_neuron(neuron, neurite_types=None):
+    """Diametrize single neuron by learning simpler diameter model from it.
 
     Args:
         neuron (mophio.mut.Morphology): neuron to consider.
-        config (dict): dict with entry 'model' and 'diameters' with corresponding dicts, if None,
-            default dict will be used.
-        apical_point_sec_ids (list): list of apical points if any.
+        neurite_types (list): list of neurite types to consider, if None basal/apical will be used
     """
-    if config is None:
-        config = {
-            "model": {
-                "taper": {"max": 1e-06, "min": -0.1},
-                "terminal_threshold": 2.0,
-                "models": ["generic"],
-                "neurite_types": ["basal", "apical"],
-            },
-            "diameters": {
-                "models": ["generic"],
-                "n_samples": 1,
-                "neurite_types": ["basal", "apical"],
-                "seed": 0,
-                "trunk_max_tries": 100,
-            },
-        }
-
-    model_params = build_model([nm.load_neuron(neuron)], config["model"])
-    if apical_point_sec_ids is not None:
-        model_params["apical_point_sec_ids"] = apical_point_sec_ids
-    build_diameters(neuron, ["basal", "apical"], model_params, config["diameters"])
+    model, _ = build_simpler_model([nm.load_neuron(neuron)], {"neurite_types": neurite_types})
+    return simpler_diametrizer(neuron, model, neurite_types)
